@@ -318,7 +318,7 @@ int doit(int t)
   }
 
   if (flagdeny) goto FINISH;
-  if (flagallow) fnrules = 0;
+  if (flagallow) fnrules = 0;  // you need to know what you are doing
 
   if (flagremotehost)
     if (dns_name(&remotehostsa,remoteip) >= 0)
