@@ -317,7 +317,7 @@ void doit(int t)
   }
 
   if (flagdeny) goto FINISH;
-  if (flagallow) fnrules = 0;
+  if (flagallow) fnrules = 0;   // you need to know what you are doing
 
 /* Early lookup of remote information (before child invoked) */
 
@@ -906,7 +906,7 @@ int main(int argc,char * const *argv)
   ndelay_off(s);
 
   if (flag1) {
-    buffer_init(&bo,write,1,bspace,sizeof(bspace));
+    buffer_init(&bo,buffer_unixwrite,1,bspace,sizeof(bspace));
     buffer_puts(&bo,localipstr);
     buffer_puts(&bo," : ");
     buffer_puts(&bo,localportstr);
